@@ -6,11 +6,18 @@ setMethod(f='mafast', signature=c('sdcMicroObj'),
         if(!is.null(obj@strataVar))
           by <- colnames(obj@origData)[obj@strataVar]
       }else if(!all(by%in%colnames(x))){
-        x <- cbind(x,obj@origData[,by[!by%in%colnames(x)]])
+        tmp <- obj@manipKeyVars[,by[by%in%colnames(obj@manipKeyVars)&!by%in%colnames(x)],drop=FALSE]
+        x <- cbind(x,tmp)
+        if(!all(by%in%colnames(x))){
+          tmp <- obj@origData[,by[!by%in%colnames(x)],drop=FALSE]
+          x <- cbind(x,tmp)
+        }
       }
         
-      if(is.null(variables))
+      if(is.null(variables)){
         variables <- colnames(obj@origData)[obj@numVars]
+        variables <- variables[!variables%in%by]
+      }
       res <- mafastWORK(x, variables=variables,by=by,aggr=aggr,measure=measure)
       obj <- nextSdcObj(obj)
       obj <- set.sdcMicroObj(obj, type="manipNumVars", input=list(as.data.frame(res[,colnames(get.sdcMicroObj(obj, type="manipNumVars"))])))
@@ -69,8 +76,8 @@ mafastWORK <- function(x,variables=colnames(x),by=NULL,aggr=3,measure=mean){
       paste(variables,"= vectoraggr(",variables,",aggr=aggr)",collapse=",",sep=""),
       "),by=BYVARIABLEFORSPLIT]")
   erg <- vector() #To get no NOTE
-  eval(parse(text=cmd))            
-  x <- x[,!colnames(x)%in%c("BYVARIABLEFORSPLIT","idvariableforresorting")]
+  eval(parse(text=cmd))       
+  x <- x[,!colnames(x)%in%c("BYVARIABLEFORSPLIT","idvariableforresorting"),drop=FALSE]
   setkey(erg,"idvariableforresorting")
   x[,variables] <- data.frame(erg[,by=idvariableforresorting])[,variables]
   return(x)
